DeviValidate class

Implementers

Constructors

DeviValidate()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isEmail(String email) → bool
Validates if the given email is in a proper email format.
isName(String name) → bool
Validates if the given name contains only alphabets and spaces.
isPassword(String password) → bool
Validates if the given password meets the required criteria.
isPhoneNumber(String phoneNumber) → bool
Validates if the given phoneNumber is in a proper phone number format.
isUrl(String url) → bool
Validates if the given url is a properly formatted URL.
isUsername(String username) → bool
Validates if the given username meets the required criteria.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited